var classIMP_1_1domino_1_1AssignmentsTable =
[
    [ "AssignmentsTable", "classIMP_1_1domino_1_1AssignmentsTable.html#a9f1c500cf37f5b266ffabae73dadbb0b", null ],
    [ "~AssignmentsTable", "classIMP_1_1domino_1_1AssignmentsTable.html#a325612e584018e745a52a9659fcf1e66", null ],
    [ "load_assignments", "classIMP_1_1domino_1_1AssignmentsTable.html#a82165fe3c39a0a5bd1005826f5121c26", null ]
];